nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Autoack

Enum Autoack 

#[repr(u8)]
pub enum Autoack { NORMAL = 0, AUTOMATIC_ACK = 1, }

Variants



NORMAL = 0

Normal, non-automatic operation. If AUTONACK = 0, an SlvPending interrupt is generated when a matching address is received. If AUTONACK = 1, received addresses are NACKed (ignored).



AUTOMATIC_ACK = 1

A header with matching SLVADR0 and matching direction as set by AUTOMATCHREAD will be ACKed immediately, allowing the master to move on to the data bytes. If the address matches SLVADR0, but the direction does not match AUTOMATCHREAD, the behavior will depend on the AUTONACK bit in the SLVADR0 register: if AUTONACK is set, then it will be Nacked; else if AUTONACK is clear, then a SlvPending interrupt is generated.

Implementations

Source

impl Autoack

pub const fn from_bits(val: u8) -> Autoack

pub const fn to_bits(self) -> u8