nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Mstcontinue

Enum Mstcontinue 

#[repr(u8)]
pub enum Mstcontinue { NO_EFFECT = 0, CONTINUE = 1, }

Variants



NO_EFFECT = 0

No effect.



CONTINUE = 1

Continue. Informs the Master function to continue to the next operation. This must done after writing transmit data, reading received data, or any other housekeeping related to the next bus operation.

Implementations

Source

impl Mstcontinue

pub const fn from_bits(val: u8) -> Mstcontinue

pub const fn to_bits(self) -> u8