#[repr(u8)]pub enum Slvcontinue {
NO_EFFECT = 0,
CONTINUE = 1,
}Variants
NO_EFFECT = 0
No effect.
CONTINUE = 1
Continue. Informs the Slave function to continue to the next operation, by clearing the SLVPENDING flag in the STAT register. This must be done after writing transmit data, reading received data, or any other housekeeping related to the next bus operation. Automatic Operation has different requirements. SLVCONTINUE should not be set unless SLVPENDING = 1.
Implementations
Sourceimpl Slvcontinue
impl Slvcontinue